Corporate Gifts in Singapore — Curated, Customisable & Ready to Ship

Browse our curated range of corporate gifts, hampers and custom gift sets designed for clients, partners and employees. Add your branding and let us handle fulfilment from ideas to delivery.

-Material: 2 Tone Nylon -Dimension: 22cm(L) x 12.5cm(W) x 22cm(H) -Function: Cooler / Warmer Bag -Color: Black; Maroon; Grey; Purple
Multipurpose Bag (49)
-Material: 12oz Laminated Canvas Ba with Strap -Dimension: 30cm(L) x 15cm(D) x 35cm(H) -Weight: +/- 256g -Colors: Red; Green; Royal Blue; Black
Canvas Bag (36)
-Colour: Red / Blue / Black -Material: Polyester -Weight: 38g ± / pc
5 Panel Cap
-Material: Aluminium -Dimension: 6.5cm(W) x 10cm(H) x 1.2cm(D) -Weight: +/- 72g -Colors: Black / Red / Grey / Sea Blue / Gold
Name Card Holder (18)
-Material :Polyester Solid Fabric with Silver Coated -Structure: Straight Handle (PVC) Auto Open 30' -Packaging: OPP Bag -Colors: Navy / Black / Red / Maroon / Royal Blue / Brown / Midnight Green
Umbrella Straight Handle with Auto Open (35)
-Wire-O calendars, 7 sheets -Calendar Size: 8"x8.5" -Ad Space: 7.5"x1.5" -Hotstamping: included front & back
Desk Calendar (Beacon Of Hope)
*FAST CHARGING CABLE - 3.0A FAST CHARGE *INPUT: USB-A & USB-C *OUTPUT: MICRO, TYPE-C, LIGHTNING *Material: Aluminium | Colour: Black *Weight: 25g / Length: 16cm *Packaging: Black Folding Box | Weight: 8g
Muticable 3 IN 2 (33C)
with 3 Gear Speeds Adjustment -Finishing: Long Life Battery with Type C Charging Port -Dimension: 16.5cm(H) -Packaging: Box
Portable Handheld Fan (68)
-Ink: Black -Weight: +/- 40g
Metal Roller Pen (27)
with i-stylus -Ink: Black -Type: Ball Pen -Colours: Black, Red, Orange, Blue
Plastic Ballpen (78)
-Calendar Size: 8" x 8.5" -Ad Space: 7.5" x 1.5" **Remarks: including logo hotstamping front & back**
Desk Calendar (Water & Life))
-Material: Stainless Steel 304 (Inner/Outer) -Capacity: 750ml -Packaging: Box -Color: Cream Beige; Baby Pink; Sky Blue; Tiffany Blue
TYESO Vacuum Bottle
-Hongbao size: 165mm*83mm -Ad Space: 75mm*18mm -STANDARD Packing: 10 pcs per packet (Please specify if require SPECIAL packing qty) **Including 1 position FRONT hotstamp only
Red Packet with Pearl Paper (775-779)
-Material: PVC -Dimension: 10.2cm(L)*13.8cm(H)*0.5cm(W) -Packaging: 250pcs/ctn with individual transparent PVC pouch -Colours: red, green and blue -GW: 13.5kgs / NW: 12.5kgs -Carton measurement: 36cm*34cm*24cm
Passport holder with Shine and Bright Cover
-Material: PET -Capacity: 500ml -Weight: +/- 144g -Packaging: Box -Colour: Black; Brown; Grey
Sport Bottle (43)
-Ink: Black -Type: Ball Pen -Material: Plastic -Colors: Red, Lime Green, Blue -Printing Area Size: 4.5cm (W) x 0.5cm (H)
Plastic Ballpen (AG)
-Capacity: 400ml -Packaging: Box -Colors: Red, Yellow, Lime Green, Sea Blue, Royal Blue, White
Colored Ceramic Mug
*Product Specifications: -FABRIC +PAPER -Hardcover -Cover Material: FABRIC -Inner Pages: 80 Sheets
Notebook with Fabric (R16)
-Material: PC -Capacity: 1000ml -Packaging: Box -Color: Navy; Black; Turquoise
Sport Bottle (58)
-Design: Landscape -Maximum Hotstamping Area: 100mm x 50mm **Remarks: Including hotstamping 1 position & Pink envelope)
CNY Greeting Card (Landscape)
-Capacity: 400ml -Material: Glass -Colors: Black; White; Brown -Packaging: Box
Glass Bottle with Straw
-Material: Stainless Steel -Capacity: 400ml -Colors: Pink, Turquoise, Grey
Auto Mug (22)
with 8pcs -Material: PU Leather Waterproof -Featuring: Protect Furniture From Heat, Moisture and Scratches caused by Hot and Cold Drinks
Full Grain Square Natural Mug Coasters
-Finished with Sew + Metal Hook -Material: Nylon -Size: 20mm -Weight: +/- 17g -Colors: White, Navy, Black, Yellow, Red, Orange, Royal Blue, Green, Sea Blue, Purple
Lanyard (14)
- Fabric : 60% Cotton - 40% Polyester - Collar - Size : XS – 3XL - Weight : 220 – 230GSM< br /> - Gender : Unisex - Eco dye - Smart; casual - Colors :
Unisex CVC Cotton Short Sleeve Polo Shirt (12)
-Material: Metal & PU Leather -Dimension: 3cm(W) x 6.5cm(H) -PU Leather: 2.1cm(W) x 4.1cm(H) - Metal -Colors: Red / Royal Blue / Black
Keychain (61)
- Quick dry - Collar - Material : 100% Microfibre - Size : XS – 3XL - Weight : 140GSM - Gender : Unisex - Colors : White/Sea Blue/Navy; Navy/White/Red; Red/White/Navy; Black/White/Grey; Sea Blue/White/Navy; Grey/White/Yellow
Unisex Microfibre Tipped Collar & Cuff Short Sleeve Polo Shirt
-Wire-O calendars with Sticky Pads, 13 sheets -Calendar Size: 6"x8.5" -Ad Space: 5.5"x1.5" -Hotstamping: included front & back
Desk Calendar with Sticky Pads (Good Vibes)
-Material: 200gsm Art card + Matt Lamination + Spot UV + 3D Matt Gold Hot Stamping -Product size: 85*165mm -Advertisement space: 35*60mm -Cover pouch material: 260gsm Art card + Matt Lamination + Spot UV -Pouch size: 105*188mm -Packing: 6 in 1 set in cover pouch, 100set/box (MOQ 100 per set x 6 design = 600pcs/box) **Including one position logo Hotstamping*
6 in 1 3D Red Packet w/Cover Pouch
-Material: Nylon jacquard & Nylon 420D -Dimension: 30cm(L)*19.5cm(W)*46cm(H) -Finished: Full lining inner with ribbon -Function: 4 compartments/ laptop lining pocket -Colours: Lime green, Orange, Navy blue
Nylon Jacquard Backpack
- Capacity: 5000 mAh - Dimensions: L 8.0 * W 4.0 × T 2.8cm - Surface Finish: Metal paint with matte UV finish (for top and bottom cases) - Port Parameters: 1. Type C port (IN/OUT bidirectional): PD20W 2. Built in cable (IN/OUT bidirectional): PD20W (Optional: Lightning cable / Type C cable; both 5 core; Type C cable as default) 3. Rear Type C male plug (OUT): 5 core PD20W 4. Wireless charging for Watch: 3W **Remarks: including 1C1P logo printing**
CAPSULE FAST CHARGING POWER BANK
*Material: Nylon Oxford *Dimension: 24.5cm(L) x 10cm(W) x 18.5cm(H) *Colors: Black; Maroon; Grey
Multipurpose Pouch (68)
-Material: Nylon 600D -Function: 2 Compartments / 1 Back pockets -Dimension: 53cm(L) x 20cm(W) x 30cm(H) -Colors: Red/Black; Lime Green/Black; Royal Blue/Black
Travelling Bag (01)
-Calendar size: 8"x 8.5" -Ad space: 7.5"x 1.5" -Sheets: 7 -Remarks: including front & back hotstamping
Wire-O Desk Calendar (Lucky Fortune)
with Padded adjustable shoulder strap -Material: Melange Polyester -Size: L48.5*W33*H23.5cm -One main zipper copartment -One front zipper pocket -Two side zipper pocket -One back mesh pocket -Packaging: 20pcs/ctn with polybag -GW.: 12kgs -Carton measurement (L*W*H): 50*30*60cm
Duffel Bag
Adjustable, multi-angle stand Suitable for tablet or mobile phone -Material: ABS -Colour: White -Weight: 200g -Open Dimension: 12.5cm x 9.0cm x 13.5cm -Packaging: White Folding Box
Multi-Angle Mobile / Tablet Stand
with Sip Lid + Cup + Handle *Capacity: 500ML / 17oz *Cap Material: PP - BPA Free *Matte - Low Glossy Spray *Anti Slip Silicone Base *Weight: 330g *Dimension: 7.9cm x 7.9cm x 21.8cm *Temperature Retention: Up to 12 Hours *Colours: Green; White; Orange *Packaging: Corrugated Folding Box
Hydro SS Vacuum Flask
*Material: Nylon 400D *Dimension: 33cm(L) x 17.5cm(W) x 41cm(H) *Weight: +/- 775g *Finished: Front Refective Tape *Function: 3 Compartments *Colour: Black; Grey
Laptop Backpack (31)
-Material: Starlight Paper (hand feel paper) -Hongbao size: 83mm*164mm (without fold) -Adverting space: 75mm*18mm -Packing: 10pcs per packet -including logo 1 position "FRONT" hotstamping only **Remarks: MOQ1000pcs per design, 100pkts X 10pcs**
Starlight Paper Red Packet (55)
Pen size:13.7(H) Colors: Gold, Blue Packaging: Individual polybag Packing: 500pcs/ctn; GW:11kgs; NW:10kgs Measurement: 30*27*15cm
Metal ballpen with color body
with Magnetip Clip -Material: PU -Colour: Blue with Magnetic Clip -Packaging: Black Hard Card Box
Ringed Business Portfolio 2-Tone Blue PU Cover
-Material: Felt -Dimension: 37.5cm(W) x 27.5cm(H) -Weight: +/-135g -Function: Multi Compartment -Colors: Black; Brown
Multipurpose Bag (73)
-Material: Eco Notepad with Pen -Paper: 70 Sheets -Packaging: OPP Bag -Dimension: 14cm(W) x 18cm(H) -Colors: Red; Green; Navy; Black
Eco Notepad with Pen (E30)
-Calendar material: 210gsm artcard -Calendar stand: 15.2*25.5cm -Calendar size: 15.2*21.5cm -Adv Space: 15.2*4cm -Adv space: 13.2*3cm -Pages: 7 sheeters **Including with 2 sides hot-stamping on front and back**
Desktop Calendar (Together Everyone Achieves More)
(Mobile phone + Earphones + Apple watch) *Dual Coils wireless charging for Phone * Wireless charger: 15W/10W/7.5W/5W/3W/2.5W *Housing: ABS *Standard color: Black or White *Input: Type-C port *Output: Wireless charging x 3 *User manual: Standard *Charging cable: 1m Type-C *Packaging: White paper box *Product size: 165*141.3*13mm *HS Code: 8543709990 **Remarks: including logo printing on one color one position**
Foldable Phone Stand with 3 in 1 Wireless Charger
3 USB PORT + SD & Micro SD Card Reader, 3.0 High Speed Data Transfer, USB-C with USB-A Connector Connect To 5 Devices At The Same Time Material: Aluminium Colour: Grey, Weight: 28g Dimension: 9.3cm x 2.0cm x 1.0cm Packaging: White Folding Box
USB Hub and Card Reader
*Design Model no.: 9927 -Material: Silk cloth (same like 9901/9902 design material) -Packing: (10pcs per packet) **Remarks: including hotstamping on 1 position at front**
Red Packet (S3)
-Material: PU Stitched -Size: 21*26cm -FEATURE:*Week-to-a-View* -BINDING:*Thread Sewn -CONTENT:*Personal Memoranda*3 year Reference Calendars*Useful Telephone Nos#Conversion Guide*Weight & Measures*Interest & Discount Tables*World Currencies*IDD*2020 Year Planners*Staff Leave Chart*World Time*Monthly Objectives*Cash Account*Annual Cash Summary*Business Meetings*Investment Portfolio*Address & Telephone*Notes*World Holidays*World Map*
Management Diary (PS161)
-Material: Wheat Fiber -Capacity: 400ml -Packaging: Box -Colors: Black / Pink / Brown
Wheat Fiber Cup (66)
-Type: Ultrasonic -Size: 24cm(H) x 18cm(L) x 8cm(W) -Weight / Thickness: 90 gm -Colors: Red / Yellow / Blue / Orange / Black
Non-woven Bag A5 Size
💬 Chat with me I'm Clara
💬 Affinity Chat